function output_vector = CDmoments(V)
%	CDmoments
%	[ meanP,varP,skewP,kurtP ] = cme_solution([ton toff km dm kp dp])
%   ton = rate into gene=ON state
%   toff = rate into gene=OFF state
%   d = rna degradation
%   c = protein degradation
%   k = rna transcription
%   j = protein translation
%
%   MODEL.
%   OFF<-->ON-->RNA-->PROTEIN
%                |       |
%                0       0
%
%   Example use from library member 3585 (Example 1.)
%
%   CDmoments([0.22361 0.018314 133.3333 2.0667 0.75 0.66667])
%   
%   ans = 
%
%       67.085       349.03       -12390  8.7864e+005
%
%   Note, output are central moments. For example, central skewness is not normalized
%   by V^(3/2) as is typical in statistics.
%
%   Solution derived in Sherman MS and Cohen BA. "A computational framework
%   for analyzing stochasticity in gene expression." If you use this code
%   in a manuscript, please cite the paper.



ton=V(1);
toff=V(2);
k=V(3);
d=V(4);
j=V(5);
c=V(6);

meanM=k*ton/(d*(ton+toff));
meanP=meanM*j/c;

varP=(j*k*ton*(c^2*d*toff + c*d^2*toff + c*d*j*toff + c*j*k*toff + d*j*k*toff + ...
    c^2*toff^2 + 2*c*d*toff^2 + d^2*toff^2 + c*j*toff^2 + d*j*toff^2 + j*k*toff^2 + ...
    c*toff^3 + d*toff^3 + j*toff^3 + c^2*d*ton + c*d^2*ton + c*d*j*ton + ...
    2*c^2*toff*ton + 4*c*d*toff*ton + 2*d^2*toff*ton + 2*c*j*toff*ton + ...
    2*d*j*toff*ton + j*k*toff*ton + 3*c*toff^2*ton + 3*d*toff^2*ton + ...
    3*j*toff^2*ton + c^2*ton^2 + 2*c*d*ton^2 + d^2*ton^2 + c*j*ton^2 + d*j*ton^2 + ...
    3*c*toff*ton^2 + 3*d*toff*ton^2 + 3*j*toff*ton^2 + c*ton^3 + d*ton^3 + j*ton^3))/ ...
    (c*d*(toff + ton)^2*(d + toff + ton)*(c^2 + c*d + c*toff + d*toff + c*ton + d*ton));

skewP=j*k*ton*(-((j^2*k^2*ton^2)/(c*d*toff+c*d*ton)^3)-(3*j*k*ton*(c^2*(toff+ton)*(d+toff+ton)+(d+toff+ton)*(d*(toff+ton)^2+j*(k*toff+(toff+ton)^2))+c*(d^2*(toff+ton)+(toff+ton)^3+d*(toff+ton)*(j+2*(toff+ton))+j*(k*toff+(toff+ton)^2))))/(c^2*d^2*(c+d)*(toff+ton)^3*(c+toff+ton)*(d+toff+ton))+(4*c^8*d^2*(d+toff+ton)*(2*d+toff+ton)+2*d^3*j^2*k^2*ton^2*(d+toff+ton)^2*(2*d+toff+ton)+2*c^7*d*(2*d+toff+ton)*(9*d^3+6*j*k*ton+2*d^2*(3*j+7*(toff+ton))+d*(5*(toff+ton)^2+6*j*(k+toff+ton)))+c*d^2*j*k*ton*(d+toff+ton)*(2*d+toff+ton)*(6*d^3*(toff+ton)+7*j*k*ton*(toff+ton)+6*d^2*((toff+ton)^2+j*(k+toff+ton))+3*d*j*(2*(toff+ton)^2+k*(2*toff+5*ton)))+c^6*(56*d^6+4*j^2*k^2*ton^2+2*d^5*(42*j+83*(toff+ton))+6*d*j*k*ton*(5*(toff+ton)^2+2*j*(k+toff+ton))+d^4*(8*j^2+167*(toff+ton)^2+6*j*(18*k+31*(toff+ton)))+2*d^2*(4*(toff+ton)^4+2*j^2*(2*k^2+(toff+ton)^2+3*k*(toff+3*ton))+3*j*(toff+ton)*(5*(toff+ton)^2+k*(5*toff+24*ton)))+d^3*(65*(toff+ton)^3+12*j^2*(2*k+toff+ton)+6*j*(22*(toff+ton)^2+k*(19*toff+37*ton))))+c^2*d*(d+toff+ton)*(2*d+toff+ton)*(7*j^2*k^2*ton^2*(toff+ton)+2*d^5*(toff+ton)^2+5*d*j^2*k*ton*(3*(toff+ton)^2+k*(3*toff+7*ton))+2*d^4*((toff+ton)^3+3*j*((toff+ton)^2+k*(toff+3*ton)))+d^3*j*(2*j*(2*k^2+2*(toff+ton)^2+k*(4*toff+9*ton))+3*(toff+ton)*(2*(toff+ton)^2+k*(2*toff+15*ton)))+d^2*j*(21*k*ton*(toff+ton)^2+j*(4*(toff+ton)^3+k^2*(4*toff+31*ton)+k*(toff+ton)*(8*toff+39*ton))))+c^5*(36*d^7+10*j^2*k^2*ton^2*(toff+ton)+2*d^6*(42*j+83*(toff+ton))+6*d^5*(4*j^2+41*(toff+ton)^2+4*j*(7*k+13*(toff+ton)))+6*d*j*k*ton*(4*(toff+ton)^3+j*(5*(toff+ton)^2+k*(5*toff+8*ton)))+d^2*(2*(toff+ton)^5+2*j^2*(5*(toff+ton)^3+3*k*(toff+ton)*(5*toff+22*ton)+k^2*(10*toff+37*ton))+3*j*(toff+ton)^2*(8*(toff+ton)^2+k*(8*toff+65*ton)))+d^4*(150*(toff+ton)^3+28*j^2*(3*k+2*(toff+ton))+j*(369*(toff+ton)^2+6*k*(51*toff+83*ton)))+3*d^3*(12*(toff+ton)^4+2*j^2*(6*k^2+7*(toff+ton)^2+k*(17*toff+31*ton))+j*(toff+ton)*(55*(toff+ton)^2+k*(53*toff+167*ton))))+c^4*(8*d^8+8*j^2*k^2*ton^2*(toff+ton)^2+d^7*(24*j+74*(toff+ton))+d^6*(16*j^2+167*(toff+ton)^2+6*j*(18*k+31*(toff+ton)))+d^4*(56*(toff+ton)^4+3*j*(toff+ton)*(95*(toff+ton)^2+6*k*(15*toff+41*ton))+2*j^2*(28*k^2+51*(toff+ton)^2+3*k*(33*toff+52*ton)))+d*j*k*ton*(toff+ton)*(6*(toff+ton)^3+j*(24*(toff+ton)^2+k*(24*toff+65*ton)))+d^3*(7*(toff+ton)^5+6*j*(toff+ton)^2*(14*(toff+ton)^2+k*(14*toff+75*ton))+j^2*(50*(toff+ton)^3+9*k*(toff+ton)*(14*toff+41*ton)+2*k^2*(35*toff+83*ton)))+d^5*(150*(toff+ton)^3+j^2*(84*k+76*(toff+ton))+j*(369*(toff+ton)^2+6*k*(51*toff+83*ton)))+d^2*j*(6*(toff+ton)^3*((toff+ton)^2+k*(toff+18*ton))+j*(8*(toff+ton)^4+3*k*(toff+ton)^2*(8*toff+55*ton)+k^2*(16*toff^2+143*toff*ton+167*ton^2))))+c^3*(12*d^8*(toff+ton)+2*j^2*k^2*ton^2*(toff+ton)^3+6*d*j^2*k*ton*(toff+ton)^2*((toff+ton)^2+k*(toff+6*ton))+12*d^7*(4*(toff+ton)^2+j*(2*k+3*(toff+ton)))+d^6*(65*(toff+ton)^3+24*j^2*(k+toff+ton)+6*j*(22*(toff+ton)^2+k*(19*toff+37*ton)))+d^4*(7*(toff+ton)^5+6*j*(toff+ton)^2*(14*(toff+ton)^2+k*(14*toff+75*ton))+j^2*(70*(toff+ton)^3+9*k*(toff+ton)*(16*toff+41*ton)+2*k^2*(35*toff+83*ton)))+d^5*(36*(toff+ton)^4+2*j^2*(18*k^2+36*(toff+ton)^2+31*k*(2*toff+3*ton))+3*j*(toff+ton)*(55*(toff+ton)^2+k*(53*toff+167*ton)))+d^2*j*(toff+ton)*(21*k*ton*(toff+ton)^3+2*j*((toff+ton)^4+3*k*(toff+ton)^2*(toff+14*ton)+k^2*(2*toff^2+40*toff*ton+75*ton^2)))+d^3*j*(3*(toff+ton)^3*(5*(toff+ton)^2+k*(5*toff+56*ton))+j*(24*(toff+ton)^4+k*(toff+ton)^2*(56*toff+285*ton)+k^2*(32*toff^2+238*toff*ton+246*ton^2)))))/(c^3*d^3*(c+d)*(2*c+d)*(c+2*d)*(toff+ton)*(c+toff+ton)*(2*c+toff+ton)*(d+toff+ton)*(c+d+toff+ton)*(2*d+toff+ton)));


kurtP=(j*k*ton*(72*c^13*d*(toff+ton)^3*(6*d^3+11*d^2*(toff+ton)+6*d*(toff+ton)^2+(toff+ton)^3)+18*d^4*j*k*ton*(toff+ton)*(d+toff+ton)^3*(2*d+toff+ton)^2*(3*d+toff+ton)*(d*(toff+ton)^2+j*(k*toff+(toff+ton)^2))^2+24*c^12*(toff+ton)^2*(6*d^2+5*d*(toff+ton)+(toff+ton)^2)*(34*d^3*(toff+ton)+9*j*k*ton*(toff+ton)+d^2*(toff+ton)*(21*j+47*(toff+ton))+d*(13*(toff+ton)^3+3*j*(7*(toff+ton)^2+k*(7*toff+3*ton))))+2*c^11*(toff+ton)*(3*d+toff+ton)*(3882*d^5*(toff+ton)^2+d^4*(toff+ton)^2*(5208*j+9125*(toff+ton))+36*j*k*ton*(toff+ton)*(13*(toff+ton)^3+6*j*(k*toff+(toff+ton)^2))+12*d^3*(toff+ton)*(36*j^2*(toff+ton)+620*(toff+ton)^3+17*j*(49*(toff+ton)^2+4*k*(7*toff+3*ton)))+2*d^2*(toff+ton)*(1235*(toff+ton)^4+108*j^2*(3*(toff+ton)^2+2*k*(3*toff+ton))+12*j*(toff+ton)*(245*(toff+ton)^2+6*k*(35*toff+32*ton)))+3*d*(91*(toff+ton)^6+72*j^2*(2*k^2*toff^2+3*k*(toff+ton)^3+(toff+ton)^4)+4*j*(toff+ton)^3*(91*(toff+ton)^2+k*(91*toff+219*ton))))+c^10*(61020*d^7*(toff+ton)^3+12*d^6*(toff+ton)^3*(10983*j+16592*(toff+ton))+18*j*k*ton*(toff+ton)*(91*(toff+ton)^6+104*j*(toff+ton)^3*(k*toff+(toff+ton)^2)+12*j^2*(k*toff+(toff+ton)^2)^2)+d^5*(toff+ton)^2*(25488*j^2*(toff+ton)+253343*(toff+ton)^3+6*j*(61201*(toff+ton)^2+3882*k*(7*toff+3*ton)))+d^2*(toff+ton)*(8351*(toff+ton)^7+72*j^3*(36*k^2*toff^2+6*(toff+ton)^4+k*(toff+ton)^2*(35*toff+33*ton))+72*j^2*(toff+ton)*(215*(toff+ton)^4+4*k^2*toff*(73*toff+51*ton)+2*k*(toff+ton)^2*(288*toff+329*ton))+2*j*(toff+ton)^4*(21931*(toff+ton)^2+10*k*(2086*toff+4455*ton)))+d^4*(toff+ton)^2*(432*j^3*(toff+ton)+159745*(toff+ton)^4+72*j^2*(805*(toff+ton)^2+372*k*(3*toff+ton))+2*j*(toff+ton)*(192479*(toff+ton)^2+9*k*(15085*toff+10419*ton)))+d^3*(toff+ton)*(52345*(toff+ton)^6+72*j^3*(toff+ton)*(11*(toff+ton)^2+6*k*(7*toff+3*ton))+144*j^2*(204*k^2*toff^2+320*(toff+ton)^4+k*(toff+ton)^2*(699*toff+419*ton))+2*j*(toff+ton)^3*(94794*(toff+ton)^2+k*(81578*toff+94335*ton)))+6*d*(82*(toff+ton)^9+24*j^2*(toff+ton)^3*(13*(toff+ton)^4+k^2*toff*(26*toff+73*ton)+k*(toff+ton)^2*(39*toff+109*ton))+13*j*(toff+ton)^6*(49*(toff+ton)^2+k*(49*toff+253*ton))+12*j^3*((toff+ton)^6+6*k^2*toff*(toff+ton)^2*(2*toff+3*ton)+k*(toff+ton)^4*(7*toff+18*ton)+6*k^3*toff*(toff^2-toff*ton+ton^2))))+3*c*d^3*(d+toff+ton)^2*(6*d^2+5*d*(toff+ton)+(toff+ton)^2)*(4*d^6*(toff+ton)^6+35*j^3*k*ton*(toff+ton)^3*(k*toff+(toff+ton)^2)^2+2*d^5*(toff+ton)^4*(3*(toff+ton)^3+2*j*(7*(toff+ton)^2+k*(7*toff+18*ton)))+2*d^4*(toff+ton)^2*((toff+ton)^6+12*j^2*(2*(toff+ton)^4+k^2*toff*(2*toff+3*ton)+2*k*(toff+ton)^2*(2*toff+3*ton))+j*(toff+ton)^3*(21*(toff+ton)^2+k*(21*toff+122*ton)))+d^3*j*(4*j*(toff+ton)^3*(18*(toff+ton)^4+4*k*(toff+ton)^2*(9*toff+29*ton)+k^2*toff*(18*toff+95*ton))+(toff+ton)^6*(14*(toff+ton)^2+k*(14*toff+201*ton))+24*j^2*(3*k*(toff+ton)^5+(toff+ton)^6+k^2*toff*(toff+ton)^2*(3*toff+2*ton)+k^3*toff*(toff^2-toff*ton+ton^2)))+d*j^2*(toff+ton)^2*(82*k*ton*(toff+ton)^3*(k*toff+(toff+ton)^2)+3*j*(4*(toff+ton)^6+2*k^2*toff*(toff+ton)^2*(6*toff+49*ton)+k*(toff+ton)^4*(12*toff+55*ton)+k^3*toff*(4*toff^2+43*toff*ton+4*ton^2)))+d^2*j*(toff+ton)*(47*k*ton*(toff+ton)^6+6*j*(toff+ton)^3*(4*(toff+ton)^4+k^2*toff*(4*toff+57*ton)+k*(toff+ton)^2*(8*toff+61*ton))+4*j^2*(9*(toff+ton)^6+k*(toff+ton)^4*(27*toff+55*ton)+k^2*toff*(toff+ton)^2*(27*toff+80*ton)+k^3*toff*(9*toff^2+25*toff*ton+9*ton^2))))+c^9*(96984*d^8*(toff+ton)^3+126*d^7*(toff+ton)^3*(2344*j+3077*(toff+ton))+36*j*k*ton*(toff+ton)^2*(41*(toff+ton)^6+91*j*(toff+ton)^3*(k*toff+(toff+ton)^2)+26*j^2*(k*toff+(toff+ton)^2)^2)+3*d^6*(toff+ton)^2*(33408*j^2*(toff+ton)+204457*(toff+ton)^3+6*j*(57029*(toff+ton)^2+3390*k*(7*toff+3*ton)))+d^5*(toff+ton)^2*(4104*j^3*(toff+ton)+494617*(toff+ton)^4+216*j^2*(1323*(toff+ton)^2+523*k*(3*toff+ton))+j*(toff+ton)*(1388443*(toff+ton)^2+204*k*(4585*toff+2928*ton)))+d^3*(toff+ton)*(51905*(toff+ton)^7+48*j^3*(558*k^2*toff^2+157*(toff+ton)^4+k*(toff+ton)^2*(778*toff+579*ton))+12*j^2*(toff+ton)*(12897*(toff+ton)^4+9*k^2*toff*(1496*toff+659*ton)+k*(toff+ton)^2*(31371*toff+27497*ton))+j*(toff+ton)^4*(322553*(toff+ton)^2+k*(297794*toff+479235*ton)))+d^4*(toff+ton)*(218113*(toff+ton)^6+36*j^3*(toff+ton)*(261*(toff+ton)^2+8*k*(101*toff+42*ton))+12*j^2*(11646*k^2*toff^2+25577*(toff+ton)^4+3*k*(toff+ton)^2*(16545*toff+8743*ton))+j*(toff+ton)^3*(928627*(toff+ton)^2+k*(770693*toff+760029*ton)))+d^2*(5996*(toff+ton)^9+12*j^2*(toff+ton)^3*(3055*(toff+ton)^4+2*k^2*toff*(2416*toff+3411*ton)+3*k*(toff+ton)^2*(2815*toff+4514*ton))+j*(toff+ton)^6*(54635*(toff+ton)^2+19*k*(2807*toff+8265*ton))+36*j^3*(71*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(140*toff+93*ton)+2*k*(toff+ton)^4*(219*toff+311*ton)+136*k^3*toff*(toff^2-toff*ton+ton^2)))+3*d*(toff+ton)*(80*(toff+ton)^9+7*j*(toff+ton)^6*(164*(toff+ton)^2+k*(164*toff+1193*ton))+4*j^2*(toff+ton)^3*(273*(toff+ton)^4+13*k*(toff+ton)^2*(63*toff+241*ton)+2*k^2*toff*(273*toff+1217*ton))+8*j^3*(13*(toff+ton)^6+12*k^2*toff*(toff+ton)^2*(13*toff+35*ton)+k*(toff+ton)^4*(91*toff+318*ton)+6*k^3*toff*(13*toff^2+4*toff*ton+13*ton^2))))+c^8*(96984*d^9*(toff+ton)^3+72*d^8*(toff+ton)^3*(5327*j+6696*(toff+ton))+18*j*k*ton*(toff+ton)^3*(40*(toff+ton)^6+164*j*(toff+ton)^3*(k*toff+(toff+ton)^2)+91*j^2*(k*toff+(toff+ton)^2)^2)+12*d^7*(toff+ton)^2*(16920*j^2*(toff+ton)+78619*(toff+ton)^3+18*j*(7812*(toff+ton)^2+449*k*(7*toff+3*ton)))+d^6*(toff+ton)^2*(15336*j^3*(toff+ton)+951695*(toff+ton)^4+864*j^2*(853*(toff+ton)^2+293*k*(3*toff+ton))+14*j*(toff+ton)*(207511*(toff+ton)^2+27*k*(5035*toff+3077*ton)))+d^4*(toff+ton)*(173663*(toff+ton)^7+6*j^3*(18828*k^2*toff^2+8107*(toff+ton)^4+k*(toff+ton)^2*(34105*toff+21597*ton))+6*j^2*(toff+ton)*(119764*(toff+ton)^4+102*k^2*toff*(989*toff+321*ton)+k*(toff+ton)^2*(265404*toff+198349*ton))+j*(toff+ton)^4*(1204238*(toff+ton)^2+3*k*(363440*toff+494617*ton)))+3*d^5*(toff+ton)*(179737*(toff+ton)^6+12*j^3*(toff+ton)*(1236*(toff+ton)^2+k*(3089*toff+1233*ton))+4*j^2*(30510*k^2*toff^2+86386*(toff+ton)^4+9*k*(toff+ton)^2*(16680*toff+8147*ton))+j*(toff+ton)^3*(844564*(toff+ton)^2+k*(684803*toff+613371*ton)))+d^3*(30237*(toff+ton)^9+7*j*(toff+ton)^6*(44100*(toff+ton)^2+k*(42373*toff+93477*ton))+6*j^2*(toff+ton)^3*(43024*(toff+ton)^4+11*k^2*toff*(5140*toff+4869*ton)+k*(toff+ton)^2*(109656*toff+132661*ton))+6*j^3*(4157*(toff+ton)^6+6*k^2*toff*(toff+ton)^2*(3910*toff+1623*ton)+k*(toff+ton)^4*(22461*toff+23765*ton)+3882*k^3*toff*(toff^2-toff*ton+ton^2)))+6*d*(toff+ton)^2*(10*(toff+ton)^9+2*j*(toff+ton)^6*(140*(toff+ton)^2+k*(140*toff+1499*ton))+j^2*(toff+ton)^3*(492*(toff+ton)^4+k^2*toff*(984*toff+6635*ton)+k*(toff+ton)^2*(1476*toff+7805*ton))+j^3*(91*(toff+ton)^6+13*k*(toff+ton)^4*(49*toff+229*ton)+4*k^2*toff*(toff+ton)^2*(273*toff+1139*ton)+k^3*toff*(546*toff^2+1033*toff*ton+546*ton^2)))+d^2*(toff+ton)*(2450*(toff+ton)^9+7*j*(toff+ton)^6*(5504*(toff+ton)^2+5*k*(1090*toff+4449*ton))+6*j^2*(toff+ton)^3*(7532*(toff+ton)^4+2*k^2*toff*(6425*toff+14846*ton)+k*(toff+ton)^2*(21048*toff+46079*ton))+6*j^3*(1001*(toff+ton)^6+5*k*(toff+ton)^4*(1259*toff+2454*ton)+4*k^2*toff*(toff+ton)^2*(2251*toff+3000*ton)+k^3*toff*(3158*toff^2-1217*toff*ton+3158*ton^2))))+c^2*d^2*(432*d^11*(toff+ton)^5+186*j^3*k*ton*(toff+ton)^7*(k*toff+(toff+ton)^2)^2+24*d^10*(toff+ton)^3*(112*(toff+ton)^3+3*j*(42*(toff+ton)^2+k*(35*toff+33*ton)))+2*d^9*(toff+ton)*(3289*(toff+ton)^6+216*j^2*(6*k^2*toff^2+12*(toff+ton)^4+k*(toff+ton)^2*(18*toff+11*ton))+12*j*(toff+ton)^3*(763*(toff+ton)^2+3*k*(231*toff+347*ton)))+d^8*(toff+ton)*(8351*(toff+ton)^7+216*j^3*(12*k^2*toff^2+12*(toff+ton)^4+k*(toff+ton)^2*(24*toff+11*ton))+144*j^2*(toff+ton)*(206*(toff+ton)^4+7*k*(toff+ton)^2*(52*toff+47*ton)+2*k^2*toff*(73*toff+51*ton))+2*j*(toff+ton)^4*(21931*(toff+ton)^2+10*k*(2086*toff+4455*ton)))+d^7*(5996*(toff+ton)^9+24*j^2*(toff+ton)^3*(2821*(toff+ton)^4+k^2*toff*(2416*toff+3411*ton)+k*(toff+ton)^2*(5387*toff+6771*ton))+j*(toff+ton)^6*(54635*(toff+ton)^2+19*k*(2807*toff+8265*ton))+72*j^3*(188*(toff+ton)^6+2*k^2*toff*(toff+ton)^2*(177*toff+56*ton)+k*(toff+ton)^4*(492*toff+311*ton)+68*k^3*toff*(toff^2-toff*ton+ton^2)))+6*d*j^2*(toff+ton)^6*(97*k*ton*(toff+ton)^3*(k*toff+(toff+ton)^2)+j*(11*(toff+ton)^6+5*k*(toff+ton)^4*(9*toff+97*ton)+5*k^2*toff*(toff+ton)^2*(11*toff+183*ton)+k^3*toff*(21*toff^2+422*toff*ton+21*ton^2)))+3*d^2*j*(toff+ton)^5*(138*k*ton*(toff+ton)^6+4*j*(toff+ton)^3*(29*(toff+ton)^4+2*k^2*toff*(16*toff+329*ton)+k*(toff+ton)^2*(61*toff+690*ton))+5*j^2*(68*(toff+ton)^6+3*k*(toff+ton)^4*(84*toff+403*ton)+4*k^2*toff*(toff+ton)^2*(73*toff+528*ton)+k^3*toff*(108*toff^2+871*toff*ton+108*ton^2)))+d^3*j*(toff+ton)^4*(6*j*(toff+ton)^3*(700*(toff+ton)^4+5*k*(toff+ton)^2*(292*toff+1603*ton)+2*k^2*toff*(380*toff+3607*ton))+(toff+ton)^6*(287*(toff+ton)^2+k*(287*toff+5550*ton))+3*j^2*(2020*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(1935*toff+7741*ton)+k*(toff+ton)^4*(6996*toff+19721*ton)+3*k^3*toff*(920*toff^2+3561*toff*ton+920*ton^2)))+d^6*(toff+ton)*(2450*(toff+ton)^9+7*j*(toff+ton)^6*(5504*(toff+ton)^2+5*k*(1090*toff+4449*ton))+6*j^2*(toff+ton)^3*(13426*(toff+ton)^4+71*k*(toff+ton)^2*(376*toff+649*ton)+2*k^2*toff*(6425*toff+14846*ton))+6*j^3*(4706*(toff+ton)^6+30*k*(toff+ton)^4*(459*toff+409*ton)+2*k^2*toff*(toff+ton)^2*(6075*toff+4427*ton)+k^3*toff*(3158*toff^2-1217*toff*ton+3158*ton^2)))+d^4*(toff+ton)^3*(47*(toff+ton)^9+5*j*(toff+ton)^6*(658*(toff+ton)^2+k*(658*toff+6135*ton))+6*j^2*(toff+ton)^3*(3460*(toff+ton)^4+10*k^2*toff*(367*toff+2064*ton)+k*(toff+ton)^2*(7142*toff+24733*ton))+3*j^3*(6088*(toff+ton)^6+7*k*(toff+ton)^4*(2856*toff+5263*ton)+8*k^2*toff*(toff+ton)^2*(2634*toff+6191*ton)+k^3*toff*(7128*toff^2+12181*toff*ton+7128*ton^2)))+d^5*(toff+ton)^2*(530*(toff+ton)^9+6*j^2*(toff+ton)^3*(9040*(toff+ton)^4+4*k*(toff+ton)^2*(4598*toff+11025*ton)+k^2*toff*(9232*toff+33141*ton))+j*(toff+ton)^6*(15470*(toff+ton)^2+k*(15428*toff+90711*ton))+3*j^3*(10150*(toff+ton)^6+6*k^2*toff*(toff+ton)^2*(5209*toff+7089*ton)+3*k*(toff+ton)^4*(10558*toff+13375*ton)+k^3*toff*(9598*toff^2+4173*toff*ton+9598*ton^2))))+c^7*(61020*d^10*(toff+ton)^3+126*d^9*(toff+ton)^3*(2344*j+3077*(toff+ton))+36*j*k*ton*(toff+ton)^4*(5*(toff+ton)^6+40*j*(toff+ton)^3*(k*toff+(toff+ton)^2)+41*j^2*(k*toff+(toff+ton)^2)^2)+12*d^8*(toff+ton)^2*(18936*j^2*(toff+ton)+78619*(toff+ton)^3+18*j*(7812*(toff+ton)^2+449*k*(7*toff+3*ton)))+2*d^7*(toff+ton)^2*(14364*j^3*(toff+ton)+589739*(toff+ton)^4+216*j^2*(2495*(toff+ton)^2+761*k*(3*toff+ton))+j*(toff+ton)*(1849421*(toff+ton)^2+36*k*(33341*toff+20088*ton)))+d^6*(toff+ton)*(837713*(toff+ton)^6+36*j^3*(toff+ton)*(3000*(toff+ton)^2+k*(6043*toff+2283*ton))+24*j^2*(24246*k^2*toff^2+82159*(toff+ton)^4+9*k*(toff+ton)^2*(14375*toff+6696*ton))+j*(toff+ton)^3*(4128173*(toff+ton)^2+6*k*(551453*toff+471714*ton)))+d^5*(toff+ton)*(347725*(toff+ton)^7+6*j^3*(42192*k^2*toff^2+26093*(toff+ton)^4+37*k*(toff+ton)^2*(2495*toff+1398*ton))+12*j^2*(toff+ton)*(151037*(toff+ton)^4+9*k^2*toff*(11888*toff+3217*ton)+k*(toff+ton)^2*(306366*toff+207511*ton))+j*(toff+ton)^4*(2570239*(toff+ton)^2+k*(2300662*toff+2855085*ton)))+d^4*(82445*(toff+ton)^9+18*j^2*(toff+ton)^3*(50174*(toff+ton)^4+k^2*toff*(56020*toff+41809*ton)+2*k*(toff+ton)^2*(58895*toff+60326*ton))+j*(toff+ton)^6*(906941*(toff+ton)^2+k*(862778*toff+1617633*ton))+3*j^3*(37150*(toff+ton)^6+36*k^2*toff*(toff+ton)^2*(4276*toff+1303*ton)+k*(toff+ton)^4*(173414*toff+150819*ton)+20340*k^3*toff*(toff^2-toff*ton+ton^2)))+3*d*(toff+ton)^3*(2*(toff+ton)^9+70*j*(toff+ton)^6*(2*(toff+ton)^2+k*(2*toff+35*ton))+4*j^2*(toff+ton)^3*(120*(toff+ton)^4+8*k*(toff+ton)^2*(45*toff+344*ton)+5*k^2*toff*(48*toff+497*ton))+j^3*(164*(toff+ton)^6+7*k*(toff+ton)^4*(164*toff+1037*ton)+2*k^2*toff*(toff+ton)^2*(984*toff+6089*ton)+k^3*toff*(984*toff^2+3935*toff*ton+984*ton^2)))+d^2*(toff+ton)^2*(530*(toff+ton)^9+6*j^2*(toff+ton)^3*(5258*(toff+ton)^4+90*k*(toff+ton)^2*(163*toff+490*ton)+k^2*toff*(9232*toff+33141*ton))+j*(toff+ton)^6*(15470*(toff+ton)^2+k*(15428*toff+90711*ton))+3*j^3*(2450*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(5807*toff+12640*ton)+3*k*(toff+ton)^4*(5126*toff+13375*ton)+k^3*toff*(9598*toff^2+4173*toff*ton+9598*ton^2)))+d^3*(toff+ton)*(10225*(toff+ton)^9+7*j*(toff+ton)^6*(24733*(toff+ton)^2+k*(24310*toff+74427*ton))+12*j^2*(toff+ton)^3*(20167*(toff+ton)^4+2*k^2*toff*(14803*toff+24137*ton)+k*(toff+ton)^2*(52188*toff+86017*ton))+3*j^3*(13674*(toff+ton)^6+2*k^2*toff*(toff+ton)^2*(46954*toff+42141*ton)+k*(toff+ton)^4*(75778*toff+108121*ton)+2*k^3*toff*(13171*toff^2-7726*toff*ton+13171*ton^2))))+c^5*(4896*d^12*(toff+ton)^3+18*d^11*(toff+ton)^3*(1736*j+3473*(toff+ton))+36*j^2*k*ton*(toff+ton)^6*(k*toff+(toff+ton)^2)*((toff+ton)^3+5*j*(k*toff+(toff+ton)^2))+d^10*(toff+ton)^2*(43200*j^2*(toff+ton)+253343*(toff+ton)^3+6*j*(61201*(toff+ton)^2+3882*k*(7*toff+3*ton)))+d^9*(toff+ton)^2*(13824*j^3*(toff+ton)+494617*(toff+ton)^4+216*j^2*(1973*(toff+ton)^2+523*k*(3*toff+ton))+j*(toff+ton)*(1388443*(toff+ton)^2+204*k*(4585*toff+2928*ton)))+3*d^8*(toff+ton)*(179737*(toff+ton)^6+12*j^3*(toff+ton)*(2871*(toff+ton)^2+k*(3817*toff+1233*ton))+4*j^2*(30510*k^2*toff^2+116489*(toff+ton)^4+9*k*(toff+ton)^2*(17875*toff+8147*ton))+j*(toff+ton)^3*(844564*(toff+ton)^2+k*(684803*toff+613371*ton)))+d^7*(toff+ton)*(347725*(toff+ton)^7+6*j^3*(42192*k^2*toff^2+45323*(toff+ton)^4+k*(toff+ton)^2*(113957*toff+51726*ton))+12*j^2*(toff+ton)*(185194*(toff+ton)^4+9*k^2*toff*(11888*toff+3217*ton)+k*(toff+ton)^2*(328335*toff+207511*ton))+j*(toff+ton)^4*(2570239*(toff+ton)^2+k*(2300662*toff+2855085*ton)))+d^6*(133694*(toff+ton)^9+6*j^2*(toff+ton)^3*(324578*(toff+ton)^4+6*k^2*toff*(47252*toff+31527*ton)+k*(toff+ton)^2*(660798*toff+589739*ton))+j*(toff+ton)^6*(1527134*(toff+ton)^2+k*(1445584*toff+2513139*ton))+3*j^3*(116798*(toff+ton)^6+36*k^2*toff*(toff+ton)^2*(7879*toff+1647*ton)+k*(toff+ton)^4*(397954*toff+264203*ton)+32328*k^3*toff*(toff^2-toff*ton+ton^2)))+3*d*j*(toff+ton)^5*(47*k*ton*(toff+ton)^6+4*j*(toff+ton)^3*(3*(toff+ton)^4+k^2*toff*(6*toff+229*ton)+k*(toff+ton)^2*(9*toff+235*ton))+2*j^2*(10*(toff+ton)^6+5*k*(toff+ton)^4*(14*toff+197*ton)+4*k^2*toff*(toff+ton)^2*(30*toff+461*ton)+k^3*toff*(60*toff^2+799*toff*ton+60*ton^2)))+d^2*j*(toff+ton)^4*(6*j*(toff+ton)^3*(440*(toff+ton)^4+5*k*(toff+ton)^2*(240*toff+1603*ton)+2*k^2*toff*(380*toff+3607*ton))+(toff+ton)^6*(287*(toff+ton)^2+k*(287*toff+5550*ton))+3*j^2*(670*(toff+ton)^6+82*k^2*toff*(toff+ton)^2*(75*toff+397*ton)+k*(toff+ton)^4*(4042*toff+19721*ton)+3*k^3*toff*(920*toff^2+3561*toff*ton+920*ton^2)))+d^4*(toff+ton)^2*(3320*(toff+ton)^9+12*j^2*(toff+ton)^3*(23330*(toff+ton)^4+4*k^2*toff*(7751*toff+18063*ton)+k*(toff+ton)^2*(55434*toff+109081*ton))+j*(toff+ton)^6*(103145*(toff+ton)^2+2*k*(51233*toff+200541*ton))+6*j^3*(16128*(toff+ton)^6+2*k*(toff+ton)^4*(37968*toff+58817*ton)+k^2*toff*(toff+ton)^2*(92361*toff+117439*ton)+5*k^3*toff*(6025*toff^2-466*toff*ton+6025*ton^2)))+2*d^5*(toff+ton)*(14735*(toff+ton)^9+24*j^2*(toff+ton)^3*(20433*(toff+ton)^4+10*k^2*toff*(2294*toff+2951*ton)+k*(toff+ton)^2*(45436*toff+58817*ton))+7*j*(toff+ton)^6*(37991*(toff+ton)^2+k*(37118*toff+93498*ton))+3*j^3*(41050*(toff+ton)^6+7*k^2*toff*(toff+ton)^2*(24013*toff+14313*ton)+2*k*(toff+ton)^4*(84217*toff+83976*ton)+4*k^3*toff*(9517*toff^2-6436*toff*ton+9517*ton^2)))+3*d^3*(toff+ton)^3*(46*(toff+ton)^9+70*j*(toff+ton)^6*(46*(toff+ton)^2+k*(46*toff+325*ton))+4*j^2*(toff+ton)^3*(3485*(toff+ton)^4+5*k^2*toff*(1056*toff+4591*ton)+2*k*(toff+ton)^2*(4405*toff+14428*ton))+j^3*(6802*(toff+ton)^6+6*k^2*toff*(toff+ton)^2*(8329*toff+20989*ton)+2*k*(toff+ton)^4*(18087*toff+46361*ton)+k^3*toff*(20022*toff^2+22255*toff*ton+20022*ton^2))))+c^4*(432*d^13*(toff+ton)^3+48*d^12*(toff+ton)^3*(63*j+226*(toff+ton))+18*j^3*k*ton*(toff+ton)^7*(k*toff+(toff+ton)^2)^2+2*d^11*(toff+ton)^2*(2592*j^2*(toff+ton)+31445*(toff+ton)^3+12*j*(2933*(toff+ton)^2+204*k*(7*toff+3*ton)))+d^10*(toff+ton)^2*(2592*j^3*(toff+ton)+159745*(toff+ton)^4+288*j^2*(353*(toff+ton)^2+93*k*(3*toff+ton))+2*j*(toff+ton)*(192479*(toff+ton)^2+9*k*(15085*toff+10419*ton)))+d^8*(toff+ton)*(173663*(toff+ton)^7+6*j^3*(18828*k^2*toff^2+23722*(toff+ton)^4+k*(toff+ton)^2*(51946*toff+21597*ton))+6*j^2*(toff+ton)*(176762*(toff+ton)^4+102*k^2*toff*(989*toff+321*ton)+k*(toff+ton)^2*(303156*toff+198349*ton))+j*(toff+ton)^4*(1204238*(toff+ton)^2+3*k*(363440*toff+494617*ton)))+d^9*(toff+ton)*(218113*(toff+ton)^6+288*j^3*(toff+ton)*(127*(toff+ton)^2+2*k*(71*toff+21*ton))+12*j^2*(11646*k^2*toff^2+40930*(toff+ton)^4+21*k*(toff+ton)^2*(2640*toff+1249*ton))+j*(toff+ton)^3*(928627*(toff+ton)^2+k*(770693*toff+760029*ton)))+d^7*(82445*(toff+ton)^9+6*j^2*(toff+ton)^3*(204888*(toff+ton)^4+3*k^2*toff*(56020*toff+41809*ton)+4*k*(toff+ton)^2*(99620*toff+90489*ton))+j*(toff+ton)^6*(906941*(toff+ton)^2+k*(862778*toff+1617633*ton))+3*j^3*(84530*(toff+ton)^6+12*k^2*toff*(toff+ton)^2*(14023*toff+2714*ton)+k*(toff+ton)^4*(250742*toff+150819*ton)+20340*k^3*toff*(toff^2-toff*ton+ton^2)))+6*d*j^2*(toff+ton)^6*(41*k*ton*(toff+ton)^3*(k*toff+(toff+ton)^2)+j*((toff+ton)^6+2*k^2*toff*(toff+ton)^2*(6*toff+199*ton)+k*(toff+ton)^4*(7*toff+205*ton)+k^3*toff*(6*toff^2+187*toff*ton+6*ton^2)))+3*d^2*j*(toff+ton)^5*(138*k*ton*(toff+ton)^6+4*j*(toff+ton)^3*(19*(toff+ton)^4+3*k*(toff+ton)^2*(17*toff+230*ton)+2*k^2*toff*(16*toff+329*ton))+5*j^2*(28*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(61*toff+540*ton)+k*(toff+ton)^4*(164*toff+1209*ton)+k^3*toff*(108*toff^2+871*toff*ton+108*ton^2)))+d^3*j*(toff+ton)^4*(6*j*(toff+ton)^3*(1160*(toff+ton)^4+5*k*(toff+ton)^2*(568*toff+2947*ton)+2*k^2*toff*(840*toff+6479*ton))+(toff+ton)^6*(679*(toff+ton)^2+k*(679*toff+9960*ton))+3*j^2*(2100*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(3615*toff+14944*ton)+k*(toff+ton)^4*(10580*toff+37991*ton)+5*k^3*toff*(1188*toff^2+3671*toff*ton+1188*ton^2)))+d^5*(toff+ton)^2*(3320*(toff+ton)^9+12*j^2*(toff+ton)^3*(26326*(toff+ton)^4+4*k^2*toff*(7751*toff+18063*ton)+k*(toff+ton)^2*(58330*toff+109081*ton))+j*(toff+ton)^6*(103145*(toff+ton)^2+2*k*(51233*toff+200541*ton))+6*j^3*(21868*(toff+ton)^6+2*k^2*toff*(toff+ton)^2*(48919*toff+55981*ton)+2*k*(toff+ton)^4*(43904*toff+58817*ton)+5*k^3*toff*(6025*toff^2-466*toff*ton+6025*ton^2)))+2*d^4*(toff+ton)^3*(97*(toff+ton)^9+35*j*(toff+ton)^6*(194*(toff+ton)^2+k*(194*toff+1263*ton))+6*j^2*(toff+ton)^3*(5625*(toff+ton)^4+134*k^2*toff*(55*toff+222*ton)+k*(toff+ton)^2*(13060*toff+37991*ton))+3*j^3*(6643*(toff+ton)^6+2*k^2*toff*(toff+ton)^2*(18669*toff+40610*ton)+k*(toff+ton)^4*(29773*toff+62720*ton)+k^3*toff*(13878*toff^2+13535*toff*ton+13878*ton^2)))+d^6*(toff+ton)*(22750*(toff+ton)^9+7*j*(toff+ton)^6*(57712*(toff+ton)^2+5*k*(11294*toff+29805*ton))+6*j^2*(toff+ton)^3*(136430*(toff+ton)^4+2*k^2*toff*(69607*toff+94726*ton)+k*(toff+ton)^2*(286402*toff+367177*ton))+3*j^3*(80826*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(66071*toff+36125*ton)+k*(toff+ton)^4*(286118*toff+253835*ton)+2*k^3*toff*(29359*toff^2-19321*toff*ton+29359*ton^2))))+c^6*(23292*d^11*(toff+ton)^3+12*d^10*(toff+ton)^3*(10983*j+16592*(toff+ton))+18*j*k*ton*(toff+ton)^5*((toff+ton)^6+20*j*(toff+ton)^3*(k*toff+(toff+ton)^2)+40*j^2*(k*toff+(toff+ton)^2)^2)+3*d^9*(toff+ton)^2*(46512*j^2*(toff+ton)+204457*(toff+ton)^3+6*j*(57029*(toff+ton)^2+3390*k*(7*toff+3*ton)))+d^8*(toff+ton)^2*(28296*j^3*(toff+ton)+951695*(toff+ton)^4+216*j^2*(4201*(toff+ton)^2+1172*k*(3*toff+ton))+14*j*(toff+ton)*(207511*(toff+ton)^2+27*k*(5035*toff+3077*ton)))+d^7*(toff+ton)*(837713*(toff+ton)^6+48*j^2*(12123*k^2*toff^2+45511*(toff+ton)^4+27*k*(toff+ton)^2*(2453*toff+1116*ton))+36*j^3*(toff+ton)*(3990*(toff+ton)^2+k*(6491*toff+2283*ton))+j*(toff+ton)^3*(4128173*(toff+ton)^2+6*k*(551453*toff+471714*ton)))+2*d^6*(toff+ton)*(218162*(toff+ton)^7+3*j^3*(54792*k^2*toff^2+46075*(toff+ton)^4+k*(toff+ton)^2*(136657*toff+68802*ton))+6*j^2*(toff+ton)*(219351*(toff+ton)^4+18*k^2*toff*(7593*toff+1933*ton)+k*(toff+ton)^2*(412056*toff+264203*ton))+j*(toff+ton)^4*(1646876*(toff+ton)^2+k*(1468600*toff+1769217*ton)))+d^5*(133694*(toff+ton)^9+6*j^2*(toff+ton)^3*(291916*(toff+ton)^4+6*k^2*toff*(47252*toff+31527*ton)+k*(toff+ton)^2*(634052*toff+589739*ton))+j*(toff+ton)^6*(1527134*(toff+ton)^2+k*(1445584*toff+2513139*ton))+3*j^3*(88308*(toff+ton)^6+12*k^2*toff*(toff+ton)^2*(22951*toff+5627*ton)+k*(toff+ton)^4*(351952*toff+264203*ton)+32328*k^3*toff*(toff^2-toff*ton+ton^2)))+6*d*j*(toff+ton)^4*((toff+ton)^6*(7*(toff+ton)^2+k*(7*toff+265*ton))+2*j*(toff+ton)^3*(30*(toff+ton)^4+5*k*(toff+ton)^2*(18*toff+221*ton)+2*k^2*toff*(30*toff+521*ton))+2*j^2*(20*(toff+ton)^6+7*k*(toff+ton)^4*(20*toff+179*ton)+k^2*toff*(toff+ton)^2*(240*toff+2239*ton)+2*k^3*toff*(60*toff^2+433*toff*ton+60*ton^2)))+d^2*(toff+ton)^3*(47*(toff+ton)^9+5*j*(toff+ton)^6*(658*(toff+ton)^2+k*(658*toff+6135*ton))+6*j^2*(toff+ton)^3*(2090*(toff+ton)^4+10*k^2*toff*(367*toff+2064*ton)+k*(toff+ton)^2*(5778*toff+24733*ton))+3*j^3*(1698*(toff+ton)^6+8*k^2*toff*(toff+ton)^2*(2013*toff+6812*ton)+k*(toff+ton)^4*(10494*toff+36841*ton)+k^3*toff*(7128*toff^2+12181*toff*ton+7128*ton^2)))+d^4*(toff+ton)*(22750*(toff+ton)^9+7*j*(toff+ton)^6*(57712*(toff+ton)^2+5*k*(11294*toff+29805*ton))+6*j^2*(toff+ton)^3*(109396*(toff+ton)^4+2*k^2*toff*(69607*toff+94726*ton)+k*(toff+ton)^2*(261534*toff+367177*ton))+3*j^3*(45616*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(60143*toff+42053*ton)+k*(toff+ton)^4*(218648*toff+253835*ton)+2*k^3*toff*(29359*toff^2-19321*toff*ton+29359*ton^2)))+d^3*(toff+ton)^2*(1850*(toff+ton)^9+j*(toff+ton)^6*(56105*(toff+ton)^2+3*k*(18606*toff+82445*ton))+6*j^2*(toff+ton)^3*(22104*(toff+ton)^4+2*k^2*toff*(16880*toff+44747*ton)+k*(toff+ton)^2*(56944*toff+129563*ton))+3*j^3*(12628*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(23330*toff+36103*ton)+k*(toff+ton)^4*(69380*toff+131909*ton)+k^3*toff*(33514*toff^2+1385*toff*ton+33514*ton^2))))+c^3*d*(792*d^12*(toff+ton)^4+105*j^3*k*ton*(toff+ton)^7*(k*toff+(toff+ton)^2)^2+24*d^11*(toff+ton)^2*(347*(toff+ton)^3+3*j*(77*(toff+ton)^2+6*k*(7*toff+3*ton)))+12*d^10*(toff+ton)^2*(2475*(toff+ton)^4+72*j^2*(11*(toff+ton)^2+3*k*(3*toff+ton))+2*j*(toff+ton)*(2303*(toff+ton)^2+4*k*(434*toff+339*ton)))+d^9*(toff+ton)*(52345*(toff+ton)^6+432*j^3*(toff+ton)*(11*(toff+ton)^2+k*(11*toff+3*ton))+144*j^2*(204*k^2*toff^2+586*(toff+ton)^4+k*(toff+ton)^2*(810*toff+419*ton))+2*j*(toff+ton)^3*(94794*(toff+ton)^2+k*(81578*toff+94335*ton)))+d^8*(toff+ton)*(51905*(toff+ton)^7+144*j^3*(186*k^2*toff^2+239*(toff+ton)^4+k*(toff+ton)^2*(479*toff+193*ton))+12*j^2*(toff+ton)*(22140*(toff+ton)^4+9*k^2*toff*(1496*toff+659*ton)+k*(toff+ton)^2*(37836*toff+27497*ton))+j*(toff+ton)^4*(322553*(toff+ton)^2+k*(297794*toff+479235*ton)))+d^7*(30237*(toff+ton)^9+7*j*(toff+ton)^6*(44100*(toff+ton)^2+k*(42373*toff+93477*ton))+6*j^2*(toff+ton)^3*(69590*(toff+ton)^4+11*k^2*toff*(5140*toff+4869*ton)+k*(toff+ton)^2*(132366*toff+132661*ton))+6*j^3*(15372*(toff+ton)^6+6*k^2*toff*(toff+ton)^2*(4555*toff+978*ton)+k*(toff+ton)^4*(41268*toff+23765*ton)+3882*k^3*toff*(toff^2-toff*ton+ton^2)))+6*d*j^2*(toff+ton)^6*(97*k*ton*(toff+ton)^3*(k*toff+(toff+ton)^2)+j*(6*(toff+ton)^6+k*(toff+ton)^4*(34*toff+485*ton)+k^2*toff*(toff+ton)^2*(49*toff+921*ton)+k^3*toff*(21*toff^2+422*toff*ton+21*ton^2)))+6*d^2*j*(toff+ton)^5*(97*k*ton*(toff+ton)^6+2*j*(toff+ton)^3*(39*(toff+ton)^4+2*k^2*toff*(26*toff+459*ton)+k*(toff+ton)^2*(91*toff+970*ton))+j^2*(170*(toff+ton)^6+395*k*(toff+ton)^4*(2*toff+11*ton)+4*k^2*toff*(toff+ton)^2*(260*toff+1897*ton)+k^3*toff*(420*toff^2+3023*toff*ton+420*ton^2)))+d^3*j*(toff+ton)^4*(6*j*(toff+ton)^3*(1360*(toff+ton)^4+5*k*(toff+ton)^2*(608*toff+2947*ton)+2*k^2*toff*(840*toff+6479*ton))+(toff+ton)^6*(679*(toff+ton)^2+k*(679*toff+9960*ton))+3*j^2*(3050*(toff+ton)^6+2*k^2*toff*(toff+ton)^2*(7785*toff+29333*ton)+k*(toff+ton)^4*(12654*toff+37991*ton)+5*k^3*toff*(1188*toff^2+3671*toff*ton+1188*ton^2)))+d^6*(toff+ton)*(10225*(toff+ton)^9+7*j*(toff+ton)^6*(24733*(toff+ton)^2+k*(24310*toff+74427*ton))+12*j^2*(toff+ton)^3*(30674*(toff+ton)^4+2*k^2*toff*(14803*toff+24137*ton)+k*(toff+ton)^2*(61997*toff+86017*ton))+3*j^3*(41354*(toff+ton)^6+2*k^2*toff*(toff+ton)^2*(56977*toff+32118*ton)+k*(toff+ton)^4*(129650*toff+108121*ton)+2*k^3*toff*(13171*toff^2-7726*toff*ton+13171*ton^2)))+3*d^4*(toff+ton)^3*(46*(toff+ton)^9+70*j*(toff+ton)^6*(46*(toff+ton)^2+k*(46*toff+325*ton))+4*j^2*(toff+ton)^3*(4555*(toff+ton)^4+5*k^2*toff*(1056*toff+4591*ton)+2*k*(toff+ton)^2*(4935*toff+14428*ton))+j^3*(13122*(toff+ton)^6+6*k^2*toff*(toff+ton)^2*(9493*toff+19825*ton)+2*k*(toff+ton)^4*(24879*toff+46361*ton)+k^3*toff*(20022*toff^2+22255*toff*ton+20022*ton^2)))+d^5*(toff+ton)^2*(1850*(toff+ton)^9+j*(toff+ton)^6*(56105*(toff+ton)^2+3*k*(18606*toff+82445*ton))+6*j^2*(toff+ton)^3*(31386*(toff+ton)^4+2*k^2*toff*(16880*toff+44747*ton)+k*(toff+ton)^2*(65966*toff+129563*ton))+3*j^3*(30898*(toff+ton)^6+4*k^2*toff*(toff+ton)^2*(27802*toff+31631*ton)+k*(toff+ton)^4*(107418*toff+131909*ton)+k^3*toff*(33514*toff^2+1385*toff*ton+33514*ton^2))))))/(c^2*d^2*(c+d)^2*(2*c+d)*(3*c+d)*(c+2*d)*(c+3*d)*(toff+ton)^4*(c+toff+ton)*(2*c+toff+ton)*(3*c+toff+ton)*(d+toff+ton)*(c+d+toff+ton)*(2*c+d+toff+ton)*(2*d+toff+ton)*(c+2*d+toff+ton)*(3*d+toff+ton));

output_vector=[meanP varP skewP kurtP];

end

